from .exceptions import WrongInputException


class SQSTrigger():
    """Get information from a SQS trigger record.

    Args:
        record (dic): SQS trigger record.

    Exceptions:
            WrongInputException
    """

    def __init__(self, record):
        self.__record = record
        try:
            self.__body = self.__record['body']
            self.__attributes = self.__record['messageAttributes']
            self.__id = self.__record['messageId']
            self.__timestamp = self.__record['attributes']['SentTimestamp']
            self.__queue = self.__record['eventSourceARN']
        except Exception:
            raise WrongInputException('Cloudwatch event')

    @property
    def body(self):
        return self.__body

    @property
    def attributes(self):
        return self.__attributes

    @property
    def id(self):
        return self.__id

    @property
    def timestamp(self):
        return self.__timestamp

    @property
    def queue(self):
        return self.__queue



from .exceptions import WrongInputException


class S3Trigger():
    """Get information from a S3 trigger record.

    Args:
        record (dic): trigger record.

    Exceptions:
            WrongInputException
    """

    def __init__(self, record):
        self.__record = record
        try:
            self.__bucket = self.__record['s3']['bucket']['name']
            key = self.__record['s3']['object']['key']
            self.__key = key.replace('+', ' ')
            self.__event = self.__record['eventName']
            self.__timestamp = self.__record['eventTime']
        except Exception:
            raise WrongInputException('S3 record')

    @property
    def bucket(self):
        return self.__bucket

    @property
    def key(self):
        return self.__key

    @property
    def event(self):
        return self.__event

    @property
    def timestamp(self):
        return self.__timestamp



from .exceptions import WrongInputException


class CloudwatchTrigger():
    """Get information from a Cloudwatch trigger.

    Args:
        event (dic): trigger event.

    Exceptions:
            WrongInputException
    """

    def __init__(self, event):
        self.__event = event
        try:
            self.__source = self.__event['source']
            self.__resource = self.__event['resources']
            self.__timestamp = self.__event['time']
            self.__id = self.__event['id']
            self.__detail = self.__event['detail']
        except Exception:
            raise WrongInputException('Cloudwatch event')

    @property
    def source(self):
        return self.__source

    @property
    def resource(self):
        return self.__resource

    @property
    def timestamp(self):
        return self.__timestamp

    @property
    def id(self):
        return self.__id

    @property
    def detail(self):
        return self.__detail





class WrongInputException(Exception):
    msg = 'Wrong trigger. This is not a {}.'

    def __init__(self, trigger_type):
        super(WrongInputException, self).__init__(
            self.msg.format(trigger_type)
        )
